==> unit-1.0.25-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTrashTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTrashTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Header header;
	public TrashTemplate.Header. _9_2_1186253000 _9_2_1186253000;
	public TrashTemplate.Header._9_2_1186253000. _10_3_0273829 _10_3_0273829;
	public TrashTemplate.Header._9_2_1186253000._10_3_0273829. Label label;
	public TrashTemplate.Header._9_2_1186253000. Count count;
	public TrashTemplate.Header. RightToolbar rightToolbar;
	public TrashTemplate.Header.RightToolbar. Search search;
	public _17_1_0521786897 _17_1_0521786897;
	public TrashTemplate._17_1_0521786897. _18_2_01914842262 _18_2_01914842262;
	public TrashToolbarTemplate toolbar;
	public TrashTemplate._17_1_0521786897._18_2_01914842262. _20_3_0167735262 _20_3_0167735262;
	public TrashTemplate._17_1_0521786897._18_2_01914842262._20_3_0167735262. TableView tableView;
	public TrashTableCatalog tableViewStamp;
	public TrashTemplate._17_1_0521786897. FiltersView filtersView;
	public TrashTemplate._17_1_0521786897.FiltersView. TableFilters tableFilters;
	public TrashTableFilters tableFiltersStamp;

    public AbstractTrashTemplate(B box) {
        super(box);
        id("trashTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (header == null) header = register(new Header(box()).<Header>id("a_90308999").owner(AbstractTrashTemplate.this));
		if (header != null) _9_2_1186253000 = header._9_2_1186253000;
		if (_9_2_1186253000 != null) _10_3_0273829 = header._9_2_1186253000._10_3_0273829;
		if (_10_3_0273829 != null) label = header._9_2_1186253000._10_3_0273829.label;
		if (_9_2_1186253000 != null) count = header._9_2_1186253000.count;
		if (header != null) rightToolbar = header.rightToolbar;
		if (rightToolbar != null) search = header.rightToolbar.search;
		if (_17_1_0521786897 == null) _17_1_0521786897 = register(new _17_1_0521786897(box()).<_17_1_0521786897>id("a740485305").owner(AbstractTrashTemplate.this));
		if (_17_1_0521786897 != null) _18_2_01914842262 = _17_1_0521786897._18_2_01914842262;
		if (_18_2_01914842262 != null) toolbar = _17_1_0521786897._18_2_01914842262.toolbar;
		if (_18_2_01914842262 != null) _20_3_0167735262 = _17_1_0521786897._18_2_01914842262._20_3_0167735262;
		if (_20_3_0167735262 != null) tableView = _17_1_0521786897._18_2_01914842262._20_3_0167735262.tableView;
		if (tableView != null) tableViewStamp = _17_1_0521786897._18_2_01914842262._20_3_0167735262.tableView.tableViewStamp;
		if (_17_1_0521786897 != null) filtersView = _17_1_0521786897.filtersView;
		if (filtersView != null) tableFilters = _17_1_0521786897.filtersView.tableFilters;
		if (tableFilters != null) tableFiltersStamp = _17_1_0521786897.filtersView.tableFilters.tableFiltersStamp;
	}

	public class Header extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TrashTemplate.Header. _9_2_1186253000 _9_2_1186253000;
		public TrashTemplate.Header. RightToolbar rightToolbar;

		public Header(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_9_2_1186253000 == null) _9_2_1186253000 = register(new _9_2_1186253000(box()).<_9_2_1186253000>id("a_996479670").owner(AbstractTrashTemplate.this));
			if (rightToolbar == null) rightToolbar = register(new RightToolbar(box()).<RightToolbar>id("a1955692997").owner(AbstractTrashTemplate.this));
		}

		public class _9_2_1186253000 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public TrashTemplate.Header._9_2_1186253000. _10_3_0273829 _10_3_0273829;
			public TrashTemplate.Header._9_2_1186253000. Count count;

			public _9_2_1186253000(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_10_3_0273829 == null) _10_3_0273829 = register(new _10_3_0273829(box()).<_10_3_0273829>id("a_2088533926").owner(AbstractTrashTemplate.this));
				if (count == null) count = register(new Count(box()).<Count>id("a_1780046763").owner(AbstractTrashTemplate.this));
			}

			public class _10_3_0273829 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public TrashTemplate.Header._9_2_1186253000._10_3_0273829. Label label;

				public _10_3_0273829(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (label == null) label = register(new Label(box()).<Label>id("a1879949647").owner(AbstractTrashTemplate.this));
				}

				public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public Label(B box) {
						super(box);
						_value("Trash");
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}

			public class Count extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public Count(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}

		public class RightToolbar extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public TrashTemplate.Header.RightToolbar. Search search;

			public RightToolbar(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (search == null) search = register(new Search(box()).<Search>id("a1235044706").owner(AbstractTrashTemplate.this));
			}

			public class Search extends io.intino.alexandria.ui.displays.components.SearchBox<io.intino.alexandria.ui.displays.notifiers.SearchBoxNotifier, B>  {

				public Search(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}
	}

	public class _17_1_0521786897 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TrashTemplate._17_1_0521786897. _18_2_01914842262 _18_2_01914842262;
		public TrashTemplate._17_1_0521786897. FiltersView filtersView;

		public _17_1_0521786897(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_18_2_01914842262 == null) _18_2_01914842262 = register(new _18_2_01914842262(box()).<_18_2_01914842262>id("a_77841715").owner(AbstractTrashTemplate.this));
			if (filtersView == null) filtersView = register(new FiltersView(box()).<FiltersView>id("a1283885600").owner(AbstractTrashTemplate.this));
		}

		public class _18_2_01914842262 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public TrashToolbarTemplate toolbar;
			public TrashTemplate._17_1_0521786897._18_2_01914842262. _20_3_0167735262 _20_3_0167735262;

			public _18_2_01914842262(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (toolbar == null) toolbar = register(new TrashToolbarTemplate((UnitBox)box()).id("a1985202717"));
				if (_20_3_0167735262 == null) _20_3_0167735262 = register(new _20_3_0167735262(box()).<_20_3_0167735262>id("a1956734787").owner(AbstractTrashTemplate.this));
			}

			public class _20_3_0167735262 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public TrashTemplate._17_1_0521786897._18_2_01914842262._20_3_0167735262. TableView tableView;

				public _20_3_0167735262(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (tableView == null) tableView = register(new TableView(box()).<TableView>id("a_715671027").owner(AbstractTrashTemplate.this));
				}

				public class TableView extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public TrashTableCatalog tableViewStamp;

					public TableView(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (tableViewStamp == null) tableViewStamp = register(new TrashTableCatalog((UnitBox)box()).id("a_1368163230"));
					}
				}
			}
		}

		public class FiltersView extends io.intino.alexandria.ui.displays.components.BlockConditional<io.intino.alexandria.ui.displays.notifiers.BlockConditionalNotifier, B>  {
			public TrashTemplate._17_1_0521786897.FiltersView. TableFilters tableFilters;

			public FiltersView(B box) {
				super(box);
			}

			@Override
			public void initConditional() {
				super.init();
				if (tableFilters == null) tableFilters = register(new TableFilters(box()).<TableFilters>id("a780472332").owner(AbstractTrashTemplate.this));
				if (tableFiltersStamp == null) tableFiltersStamp = _17_1_0521786897.filtersView.tableFilters.tableFiltersStamp;
			}

			public class TableFilters extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public TrashTableFilters tableFiltersStamp;

				public TableFilters(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (tableFiltersStamp == null) tableFiltersStamp = register(new TrashTableFilters((UnitBox)box()).id("a1069567491"));
				}
			}
		}
	}
}

==> unit-1.1.1-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTrashTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTrashTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Header header;
	public TrashTemplate.Header. _9_2_1186253000 _9_2_1186253000;
	public TrashTemplate.Header._9_2_1186253000. _10_3_0273829 _10_3_0273829;
	public TrashTemplate.Header._9_2_1186253000._10_3_0273829. Label label;
	public TrashTemplate.Header._9_2_1186253000. Count count;
	public TrashTemplate.Header. RightToolbar rightToolbar;
	public TrashTemplate.Header.RightToolbar. Search search;
	public _17_1_0521786897 _17_1_0521786897;
	public TrashTemplate._17_1_0521786897. _18_2_01914842262 _18_2_01914842262;
	public TrashToolbarTemplate toolbar;
	public TrashTemplate._17_1_0521786897._18_2_01914842262. _20_3_0167735262 _20_3_0167735262;
	public TrashTemplate._17_1_0521786897._18_2_01914842262._20_3_0167735262. TableView tableView;
	public TrashTableCatalog tableViewStamp;
	public TrashTemplate._17_1_0521786897. FiltersView filtersView;
	public TrashTemplate._17_1_0521786897.FiltersView. TableFilters tableFilters;
	public TrashTableFilters tableFiltersStamp;

    public AbstractTrashTemplate(B box) {
        super(box);
        id("trashTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (header == null) header = register(new Header(box()).<Header>id("a_90308999").owner(AbstractTrashTemplate.this));
		if (header != null) _9_2_1186253000 = header._9_2_1186253000;
		if (_9_2_1186253000 != null) _10_3_0273829 = header._9_2_1186253000._10_3_0273829;
		if (_10_3_0273829 != null) label = header._9_2_1186253000._10_3_0273829.label;
		if (_9_2_1186253000 != null) count = header._9_2_1186253000.count;
		if (header != null) rightToolbar = header.rightToolbar;
		if (rightToolbar != null) search = header.rightToolbar.search;
		if (_17_1_0521786897 == null) _17_1_0521786897 = register(new _17_1_0521786897(box()).<_17_1_0521786897>id("a740485305").owner(AbstractTrashTemplate.this));
		if (_17_1_0521786897 != null) _18_2_01914842262 = _17_1_0521786897._18_2_01914842262;
		if (_18_2_01914842262 != null) toolbar = _17_1_0521786897._18_2_01914842262.toolbar;
		if (_18_2_01914842262 != null) _20_3_0167735262 = _17_1_0521786897._18_2_01914842262._20_3_0167735262;
		if (_20_3_0167735262 != null) tableView = _17_1_0521786897._18_2_01914842262._20_3_0167735262.tableView;
		if (tableView != null) tableViewStamp = _17_1_0521786897._18_2_01914842262._20_3_0167735262.tableView.tableViewStamp;
		if (_17_1_0521786897 != null) filtersView = _17_1_0521786897.filtersView;
		if (filtersView != null) tableFilters = _17_1_0521786897.filtersView.tableFilters;
		if (tableFilters != null) tableFiltersStamp = _17_1_0521786897.filtersView.tableFilters.tableFiltersStamp;
	}

    @Override
    public void remove() {
        super.remove();
	    if (header != null) header.unregister();
	    if (_17_1_0521786897 != null) _17_1_0521786897.unregister();
	}

	public class Header extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TrashTemplate.Header. _9_2_1186253000 _9_2_1186253000;
		public TrashTemplate.Header. RightToolbar rightToolbar;

		public Header(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_9_2_1186253000 == null) _9_2_1186253000 = register(new _9_2_1186253000(box()).<_9_2_1186253000>id("a_996479670").owner(AbstractTrashTemplate.this));
			if (rightToolbar == null) rightToolbar = register(new RightToolbar(box()).<RightToolbar>id("a1955692997").owner(AbstractTrashTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_9_2_1186253000 != null) _9_2_1186253000.unregister();
			if (rightToolbar != null) rightToolbar.unregister();
		}

		public class _9_2_1186253000 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public TrashTemplate.Header._9_2_1186253000. _10_3_0273829 _10_3_0273829;
			public TrashTemplate.Header._9_2_1186253000. Count count;

			public _9_2_1186253000(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_10_3_0273829 == null) _10_3_0273829 = register(new _10_3_0273829(box()).<_10_3_0273829>id("a_2088533926").owner(AbstractTrashTemplate.this));
				if (count == null) count = register(new Count(box()).<Count>id("a_1780046763").owner(AbstractTrashTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_10_3_0273829 != null) _10_3_0273829.unregister();
				if (count != null) count.unregister();
			}

			public class _10_3_0273829 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public TrashTemplate.Header._9_2_1186253000._10_3_0273829. Label label;

				public _10_3_0273829(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (label == null) label = register(new Label(box()).<Label>id("a1879949647").owner(AbstractTrashTemplate.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (label != null) label.unregister();
				}

				public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public Label(B box) {
						super(box);
						_value("Trash");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}

			public class Count extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public Count(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}

		public class RightToolbar extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public TrashTemplate.Header.RightToolbar. Search search;

			public RightToolbar(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (search == null) search = register(new Search(box()).<Search>id("a1235044706").owner(AbstractTrashTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (search != null) search.unregister();
			}

			public class Search extends io.intino.alexandria.ui.displays.components.SearchBox<io.intino.alexandria.ui.displays.notifiers.SearchBoxNotifier, B>  {

				public Search(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}
	}

	public class _17_1_0521786897 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TrashTemplate._17_1_0521786897. _18_2_01914842262 _18_2_01914842262;
		public TrashTemplate._17_1_0521786897. FiltersView filtersView;

		public _17_1_0521786897(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_18_2_01914842262 == null) _18_2_01914842262 = register(new _18_2_01914842262(box()).<_18_2_01914842262>id("a_77841715").owner(AbstractTrashTemplate.this));
			if (filtersView == null) filtersView = register(new FiltersView(box()).<FiltersView>id("a1283885600").owner(AbstractTrashTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_18_2_01914842262 != null) _18_2_01914842262.unregister();
			if (filtersView != null) filtersView.unregister();
		}

		public class _18_2_01914842262 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public TrashToolbarTemplate toolbar;
			public TrashTemplate._17_1_0521786897._18_2_01914842262. _20_3_0167735262 _20_3_0167735262;

			public _18_2_01914842262(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (toolbar == null) toolbar = register(new TrashToolbarTemplate((UnitBox)box()).id("a1985202717"));
				if (_20_3_0167735262 == null) _20_3_0167735262 = register(new _20_3_0167735262(box()).<_20_3_0167735262>id("a1956734787").owner(AbstractTrashTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (toolbar != null) toolbar.unregister();
				if (_20_3_0167735262 != null) _20_3_0167735262.unregister();
			}

			public class _20_3_0167735262 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public TrashTemplate._17_1_0521786897._18_2_01914842262._20_3_0167735262. TableView tableView;

				public _20_3_0167735262(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (tableView == null) tableView = register(new TableView(box()).<TableView>id("a_715671027").owner(AbstractTrashTemplate.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (tableView != null) tableView.unregister();
				}

				public class TableView extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public TrashTableCatalog tableViewStamp;

					public TableView(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (tableViewStamp == null) tableViewStamp = register(new TrashTableCatalog((UnitBox)box()).id("a_1368163230"));
					}

					@Override
					public void unregister() {
					    super.unregister();
						if (tableViewStamp != null) tableViewStamp.unregister();
					}
				}
			}
		}

		public class FiltersView extends io.intino.alexandria.ui.displays.components.BlockConditional<io.intino.alexandria.ui.displays.notifiers.BlockConditionalNotifier, B>  {
			public TrashTemplate._17_1_0521786897.FiltersView. TableFilters tableFilters;

			public FiltersView(B box) {
				super(box);
			}

			@Override
			public void initConditional() {
				super.init();
				if (tableFilters == null) tableFilters = register(new TableFilters(box()).<TableFilters>id("a780472332").owner(AbstractTrashTemplate.this));
				if (tableFiltersStamp == null) tableFiltersStamp = _17_1_0521786897.filtersView.tableFilters.tableFiltersStamp;
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (tableFilters != null) tableFilters.unregister();
			}

			public class TableFilters extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public TrashTableFilters tableFiltersStamp;

				public TableFilters(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (tableFiltersStamp == null) tableFiltersStamp = register(new TrashTableFilters((UnitBox)box()).id("a1069567491"));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (tableFiltersStamp != null) tableFiltersStamp.unregister();
				}
			}
		}
	}
}
